Expectation
===========

.. currentmodule:: pqp.symbols

.. autoclass:: Expectation
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Expectation.copy
      ~Expectation.r_adapt_map
      ~Expectation.r_map
      ~Expectation.sorted
      ~Expectation.syntactic_eq
      ~Expectation.to_latex

   .. rubric:: Methods Documentation

   .. automethod:: copy
   .. automethod:: r_adapt_map
   .. automethod:: r_map
   .. automethod:: sorted
   .. automethod:: syntactic_eq
   .. automethod:: to_latex
